# StringCalculator
 Calculator that solves string math expression

`pip install StringCalculator`

```
from StringCalculator import SolveMathProblem

result = SolveMathProblem("5^5*6+3-15")

print(result)
```
output:
> 18738.0
